Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Kinesis Analytics V2.

Actions, resources, and condition keys for Amazon Kinesis Analytics V2 - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Kinesis Analytics V2

Amazon Kinesis Analytics V2 (service prefix: `kinesisanalytics` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon Kinesis Analytics V2
- Resource types defined by Amazon Kinesis Analytics V2
- Condition keys for Amazon Kinesis Analytics V2

## Actions defined by Amazon Kinesis Analytics V2

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddApplicationCloudWatchLoggingOption | Adds cloudwatch logging option to the application. | Write | application* |  |
AddApplicationInput | Adds input to the application. | Write | application* |  |
AddApplicationInputProcessingConfiguration | Adds input processing configuration to the application. | Write | application* |  |
AddApplicationOutput | Adds output to the application. | Write | application* |  |
AddApplicationReferenceDataSource | Adds reference data source to the application. | Write | application* |  |
AddApplicationVpcConfiguration | Adds VPC configuration to the application. | Write | application* |  |
CreateApplication | Creates an application. | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateApplicationSnapshot | Creates a snapshot for an application. | Write | application* |  |
DeleteApplication | Deletes the application. | Write | application* |  |
DeleteApplicationCloudWatchLoggingOption | Deletes the specified cloudwatch logging option of the application. | Write | application* |  |
DeleteApplicationInputProcessingConfiguration | Deletes the specified input processing configuration of the application. | Write | application* |  |
DeleteApplicationOutput | Deletes the specified output of the application. | Write | application* |  |
DeleteApplicationReferenceDataSource | Deletes the specified reference data source of the application. | Write | application* |  |
DeleteApplicationSnapshot | Deletes a snapshot for an application. | Write | application* |  |
DeleteApplicationVpcConfiguration | Deletes the specified VPC configuration of the application. | Write | application* |  |
DescribeApplication | Describes the specified application. | Read | application* |  |
DescribeApplicationSnapshot | Describes an application snapshot. | Read | application* |  |
DiscoverInputSchema | Discovers the input schema for the application. | Read |  |  |
ListApplicationSnapshots | Lists the snapshots for an application. | Read | application* |  |
ListApplications | List applications for the account | List |  |  |
ListTagsForResource | Fetch the tags associated with the application. | Read | application* |  |
StartApplication | Starts the application. | Write | application* |  |
StopApplication | Stops the application. | Write | application* |  |
TagResource | Add tags to the application. | Tagging | application* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Remove the specified tags from the application. | Tagging | application* |  |
| aws:TagKeys |
UpdateApplication | Updates the application. | Write | application* |  |

## Resource types defined by Amazon Kinesis Analytics V2

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
application | `arn:$ { Partition}:kinesisanalytics:$ { Region}:$ { Account}:application/$ { ApplicationName}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Kinesis Analytics V2

Amazon Kinesis Analytics V2 defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the allowed set of values for each of the tags | String
aws:ResourceTag/${TagKey} | Filters actions based on tag-value assoicated with the resource | String
aws:TagKeys | Filters actions based on the presence of mandatory tag keys in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.